load_config_file

Function load_config_file 

pub fn load_config_file() -> Option<File>
Load the configuration file from the standard config path.

Returns None if no config file exists or if loading fails.