Module reporting

Module reporting 

Result assembly and grading.

This module handles building test results from individual test runs and computing grades/ratings.

Structs

TestResultBuilder
Builder for constructing TestResult from test runs.

Functions

compute_download_grade
compute_overall_grade
compute_upload_grade

Type Aliases

Report
Alias for a full test result that can be persisted as a report.