pub enum Error {
Show 14 variants
NetworkError(Error),
ServerListFetch(Error),
DownloadTest(Error),
UploadTest(Error),
DownloadFailure(String),
UploadFailure(String),
IpDiscovery(Error),
ParseXml(Error),
ParseJson(Error),
DeserializeXml(DeError),
Csv(Error),
ServerNotFound(String),
IoError(Error),
Context {
msg: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
}Expand description
Unified error type for netspeed-cli operations.
This enum preserves the original error cause chains by storing
the underlying errors directly, enabling better debugging and
error reporting via the std::error::Error::source() method.
Variants
NetworkError(Error)
Network-related errors from HTTP requests
ServerListFetch(Error)
Failed to fetch the server list from speedtest.net
DownloadTest(Error)
Failed during download bandwidth test
UploadTest(Error)
Failed during upload bandwidth test
DownloadFailure(String)
Download test failed for a non-HTTP reason
UploadFailure(String)
Upload test failed for a non-HTTP reason
IpDiscovery(Error)
Failed to discover client IP address
ParseXml(Error)
XML parsing errors
ParseJson(Error)
JSON parsing/serialization errors
DeserializeXml(DeError)
XML deserialization errors
Csv(Error)
CSV parsing/serialization errors
ServerNotFound(String)
Server selection errors
IoError(Error)
I/O errors from file operations
Context
Application-specific errors with context
Implementations
Sourceimpl Error
impl Error
Sourcepub fn context(msg: impl Into<String>) -> Self
pub fn context(msg: impl Into<String>) -> Self
Create a contextual error with an optional source error.
Sourcepub fn with_source(
msg: impl Into<String>,
source: impl Error + Send + Sync + 'static,
) -> Self
pub fn with_source( msg: impl Into<String>, source: impl Error + Send + Sync + 'static, ) -> Self
Create a contextual error with a source error chain.
Sourcepub fn category(&self) -> ErrorCategory
pub fn category(&self) -> ErrorCategory
Get the category for this error.