pub fn resolve_output_format(
config: &Config,
dl_result: &TestRunResult,
ul_result: &TestRunResult,
elapsed: Duration,
) -> OutputFormatExpand description
Resolve the active output format from config and test results.
pub fn resolve_output_format(
config: &Config,
dl_result: &TestRunResult,
ul_result: &TestRunResult,
elapsed: Duration,
) -> OutputFormatResolve the active output format from config and test results.