pub fn create_spinner(message: &str) -> ProgressBarExpand description
Simple spinner for non-speed phases (server fetch, ping).
Panics
Panics if the spinner template string is invalid (should never happen).
pub fn create_spinner(message: &str) -> ProgressBarSimple spinner for non-speed phases (server fetch, ping).
Panics if the spinner template string is invalid (should never happen).