pub fn select_best_server(servers: &[Server]) -> Result<Server, SpeedtestError>Expand description
Select the best server from a list, preferring the closest by distance.
Errors
Returns SpeedtestError::ServerNotFound if the server list is empty.
pub fn select_best_server(servers: &[Server]) -> Result<Server, SpeedtestError>Select the best server from a list, preferring the closest by distance.
Returns SpeedtestError::ServerNotFound if the server list is empty.