Result assembly and grading.
This module handles building test results from individual test runs and computing grades/ratings.
Structs
- Test
Result Builder - Builder for constructing
TestResultfrom test runs.
Functions
Type Aliases
- Report
- Alias for a full test result that can be persisted as a report.