Centralized test configuration constants.
This module consolidates all magic numbers used across download/upload tests, making it easy to tune test behavior and avoid inconsistent values.
Usage
use netspeed_cli::test_config::TestConfig;
let config = TestConfig::default();
println!("rounds: {}, streams: {}, interval: {}ms",
config.download_rounds, config.stream_count, config.sample_interval_ms);Structs
- Test
Config - Centralized test configuration for bandwidth measurement.